# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class BondingModeEnum(object):

    """Implementation of the 'BondingMode' enum.
    Specifies the new bonding mode. 'kActiveBackup' indicates active backup
    bonding mode. 'k802_3ad' indicates 802.3ad bonding mode.


    Attributes:
        KACTIVEBACKUP: TODO: type description here.
        K802_3AD: TODO: type description here.

    """

    KACTIVEBACKUP = 'kActiveBackup'

    K802_3AD = 'k802_3ad'
